pyhsm.basic_cmd.YHSM_Cmd_Temp_Key_Load

Package pyhsm :: Module basic_cmd :: Class YHSM_Cmd_Temp_Key_Load |
[frames] | no frames]

# Class YHSM_Cmd_Temp_Key_Load

    cmd.YHSM_Cmd --+
                   |
                  YHSM_Cmd_Temp_Key_Load

Load an AEAD into the phantom key handle 0xffffffff.

The `aead' is either a YHSM_GeneratedAEAD, or a string.

Instance Methods
__init__(self, stick, nonce, key_handle, aead) The base class for all YSM_ commands. |
bool |
parse_result(self, data) Parse result of pyhsm.defines.YSM_TEMP_KEY_LOAD command. |
Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
| status = `None`
Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### __init__(self, stick, nonce, key_handle, aead) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)

### parse_result(self, data) |
Parse result of pyhsm.defines.YSM_TEMP_KEY_LOAD command. Returns: bool Only returns (True) on successful load Raises: `pyhsm.exception.YHSM_CommandFailed` - YubiHSM failed to load key Overrides: cmd.YHSM_Cmd.parse_result